<a href="https://github.com/wiseupdata/wiseupdata">
  <img align="left" alt="Wise Up Data's Instagram" width="22px" src="https://raw.githubusercontent.com/wiseupdata/wiseupdata/main/assets/instagram.png" />   
</a> 
<a href="https://github.com/wiseupdata/wiseupdata">
  <img align="left" alt="wise Up Data's Discord" width="22px" src="https://raw.githubusercontent.com/wiseupdata/wiseupdata/main/assets/discord.png" />
</a>
<a href="https://github.com/wiseupdata/wiseupdata">
  <img align="left" alt="wise Up Data | Twitter" width="22px" src="https://raw.githubusercontent.com/wiseupdata/wiseupdata/main/assets/twitter.png" />
</a>
<a href="https://github.com/wiseupdata/wiseupdata">
  <img align="left" alt="wise Up Data's LinkedIN" width="22px" src="https://raw.githubusercontent.com/wiseupdata/wiseupdata/main/assets/linkedin.png" />
</a>

![visitors](https://visitor-badge.glitch.me/badge?page_id=wiseupdata.pysparkplus&left_color=green&right_color=black)
![license](https://img.shields.io/github/license/wiseupdata/pysparkplus)
[![pypi](https://img.shields.io/pypi/v/pysparkplus?color=green)](https://pypi.python.org/pypi/pysparkplus)
[![downloads](https://pepy.tech/badge/pysparkplus/month)](https://pepy.tech/project/pysparkplus)
[![versions](https://img.shields.io/pypi/pyversions/pysparkplus.svg)](https://github.com/wiseupdata/pysparkplus)

---

<a href="https://github.com/wiseupdata/wiseupdata">
<img align="left" alt="img" src="https://raw.githubusercontent.com/wiseupdata/pysparkplus/main/assets/imgs/pyspark.png" width="300" />
</a>

<h1>
Pyspark extra functions ❤️
</h1>

<br>
<br>
<br>
<br>
<br>
<br>
<br>
<br>

[Documentation](https://wiseupdata.github.io/pysparkplus/index.html)  🚀

<br>

## Features ✨️

- Wrapper Class!
- Simple use!
- Made with A.I. contribution 🤖 

<br>
</a>

<br>
<br>
<br>

* [Documentation and examples! ](https://wiseupdata.github.io/pysparkplus/index.html)! 
<br>
<br>


<br>

### Development on go!


<br>

# References 🌍 🗄️

1. [Pyspark+](https://wiseupdata.github.io/pysparkplus/index.html)
1. [Wise Up Data](https://github.com/wiseupdata)
1. [Emojis](https://github.com/wiseupdata/emojis)

<br><br>
---

#### Maintainer 🤗 👨‍💻

Sivio Liborio

📧 silvio.liborio@wiseupdata.com

<a href="https://www.linkedin.com/in/silvio-de-melo-liborio">silvio-de-melo-liborio <img align="left" alt="LinkedIN" width="18px" src="https://raw.githubusercontent.com/wiseupdata/wsl-latest/main/assets/linkedin.svg" />
</a>
